@@ -14,7 +14,7 @@ use DBD::SQLite  1.27 ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.47';
+	$VERSION = '1.48';
 }
 
 # Support for the 'prune' option
@@ -45,18 +45,26 @@ sub import {
 	}
 
 	# Check params and apply defaults
-	my %params = ();
+	my %params = (
+		# Simple defaults here, complex defaults later
+		package    => scalar(caller),
+		create     => 0,
+		cleanup    => '',
+		array      => 0,
+		xsaccessor => 0,
+		shim       => 0,
+		tables     => 1,
+		views      => 0,
+		x_update   => 0,
+	);
 	if ( defined Params::Util::_STRING($_[1]) ) {
 		# Support the short form "use ORLite 'db.sqlite'"
-		%params = ( file => $_[1] );
+		$params{file} = $_[1];
 	} elsif ( Params::Util::_HASHLIKE($_[1]) ) {
-		%params = %{ $_[1] };
+		%params = ( %params, %{$_[1]} );
 	} else {
 		Carp::croak("Missing, empty or invalid params HASH");
 	}
-	unless ( defined $params{create} ) {
-		$params{create} = 0;
-	}
 	unless (
 		defined Params::Util::_STRING($params{file})
 		and (
@@ -70,27 +78,6 @@ sub import {
 	unless ( defined $params{readonly} ) {
 		$params{readonly} = $params{create} ? 0 : ! -w $params{file};
 	}
-	unless ( defined $params{cleanup} ) {
-		$params{cleanup} = '';
-	}
-	unless ( defined $params{array} ) {
-		$params{array} = 0;
-	}
-	unless ( defined $params{xsaccessor} ) {
-		$params{xsaccessor} = 0;
-	}
-	unless ( defined $params{tables} ) {
-		$params{tables} = 1;
-	}
-	unless ( defined $params{views} ) {
-		$params{views} = 0;
-	}
-	unless ( defined $params{x_update} ) {
-		$params{x_update} = 0;
-	}
-	unless ( defined $params{package} ) {
-		$params{package} = scalar caller;
-	}
 	unless ( Params::Util::_CLASS($params{package}) ) {
 		Carp::croak("Missing or invalid package class");
 	}
@@ -470,10 +457,27 @@ END_PERL
 				? '{}'
 				: '{ Slice => {} }';
 
-			# Generate the elements in all packages
-			$code .= <<"END_PERL";
+			# Generate the package header
+			if ( $params{shim} ) {
+				# Generate a shim-wrapper class
+				$code .= <<"END_PERL";
 package $table->{class};
 
+\@$table->{class}::ISA = '$table->{class}::Shim';
+
+package $table->{class}::Shim;
+
+END_PERL
+			} else {
+				# Plain vanilla package header
+				$code .= <<"END_PERL";
+package $table->{class};
+
+END_PERL
+			}
+
+			# Generate the common elements for all classes
+			$code .= <<"END_PERL";
 sub base { '$pkg' }
 
 sub table { '$table->{name}' }
@@ -1030,7 +1034,7 @@ of generating it each time from scratch.
 
 =head2 cleanup
 
-When working with embedded SQLite database containing rapidly changing
+When working with embedded SQLite databases containing rapidly changing
 state data, it is important for database performance and general health
 to make sure you VACUUM or ANALYZE the database regularly.
 
@@ -1057,6 +1061,35 @@ cleanup operation will be made pointless when C<prune> deletes the file.
 
 By default, the C<prune> option is set to false.
 
+=head2 shim
+
+In some situtations you may wish to make extensive changes to the behaviour
+of the classes and methods generated by ORLite. Under normal circumstances
+all code is generated into the table class directly, which can make
+overriding method difficult.
+
+The C<shim> option will make ORLite generate all of it's methods into a
+seperate C<Foo::TableName::Shim> class, and leave the main table class
+C<Foo::TableName> as a transparent subclass of the shim.
+
+This allows you to alter the behaviour of a table class without having
+to do nasty tricks with symbol tables in order to alter or replace methods.
+
+  package My::Person;
+  
+  # Write a log message when we create a new object
+  sub create {
+      my $class = shift;
+      my $self  = SUPER::create(@_);
+      my $name  = $self->name;
+      print LOG "Created new person '$name'\n";
+      return $self;
+  }
+
+The C<shim> option is global. It will alter the structure of all table
+classes at once. However, unless you are making alterations to a class
+the impact of this different class structure should be zero.
+
 =head1 ROOT PACKAGE METHODS
 
 All ORLite root packages receive an identical set of methods for
@@ -1602,11 +1635,11 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<ORLite::Mirror>, L<ORLite::Migrate>
+L<ORLite::Mirror>, L<ORLite::Migrate>, L<ORLite::Pod>
 
 =head1 COPYRIGHT
 
-Copyright 2008 - 2010 Adam Kennedy.
+Copyright 2008 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
